@@ -1,5 +1,7 @@
 /*
-© 2020 Red Hat, Inc.
+SPDX-License-Identifier: Apache-2.0
+
+Copyright Contributors to the Submariner project.
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
@@ -13,6 +15,8 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */
+
+// Package gomega provides Gomega matchers used in our tests.
 package gomega
 
 import (
@@ -27,6 +31,9 @@ type containErrorSubstring struct {
 	expected error
 }
 
+// ContainErrorSubstring checks whether the actual error’s error message
+// contains the expected error’s error message, not as an exact match but
+// as a substring.
 func ContainErrorSubstring(expected error) gomegaTypes.GomegaMatcher {
 	return &containErrorSubstring{expected}
 }
