@@ -1,5 +1,7 @@
 /*
-© 2020 Red Hat, Inc.
+SPDX-License-Identifier: Apache-2.0
+
+Copyright Contributors to the Submariner project.
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
@@ -13,6 +15,8 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */
+
+// Package workqueue provides a simplified wrapper interface for Kubernetes workqueues.
 package workqueue
 
 import (
